@@ -1,48 +1,10 @@
 from sly import Parser
 
-from mindsdb_sql.ast import Constant, Identifier, Select, BinaryOperation, UnaryOperation, Join, NullConstant, TypeCast
-from mindsdb_sql.ast.base import ASTNode
-from mindsdb_sql.ast.operation import Operation, Function
-from mindsdb_sql.ast.order_by import OrderBy
-from mindsdb_sql.ast.tuple import Tuple
+from mindsdb_sql.ast import (ASTNode, Constant, Identifier, Select, BinaryOperation, UnaryOperation, Join, NullConstant,
+                             TypeCast, Tuple, OrderBy, Operation, Function, Parameter)
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.lexer import SQLLexer
-
-
-def ensure_select_keyword_order(select, operation):
-    op_to_attr = {
-        'FROM': select.from_table,
-        'WHERE': select.where,
-        'GROUP BY': select.group_by,
-        'HAVING': select.having,
-        'ORDER BY': select.order_by,
-        'LIMIT': select.limit,
-        'OFFSET': select.offset,
-    }
-
-    requirements = {
-        'WHERE': ['FROM'],
-        'GROUP BY': ['FROM'],
-        'ORDER BY': ['FROM'],
-        'HAVING': ['GROUP BY'],
-    }
-
-    precedence = ['FROM', 'WHERE', 'GROUP BY', 'HAVING', 'ORDER BY', 'LIMIT', 'OFFSET']
-
-    if op_to_attr[operation]:
-        raise ParsingException(f"Duplicate {operation} clause. Only one {operation} allowed per SELECT.")
-
-    op_requires = requirements.get(operation, [])
-
-    for req in op_requires:
-        if not op_to_attr[req]:
-            raise ParsingException(f"{operation} requires {req}")
-
-    op_precedence_pos = precedence.index(operation)
-
-    for next_op in precedence[op_precedence_pos:]:
-        if op_to_attr[next_op]:
-            raise ParsingException(f"{operation} must go after {next_op}")
+from mindsdb_sql.utils import ensure_select_keyword_order
 
 
 class SQLParser(Parser):
@@ -201,6 +163,10 @@ class SQLParser(Parser):
     def table_or_subquery(self, p):
         return p.identifier
 
+    @_('parameter')
+    def table_or_subquery(self, p):
+        return p.parameter
+
     @_('LEFT_JOIN',
         'RIGHT_JOIN',
         'INNER_JOIN',
@@ -353,6 +319,10 @@ class SQLParser(Parser):
     def expr(self, p):
         return p.identifier
 
+    @_('parameter')
+    def expr(self, p):
+        return p.parameter
+
     @_('constant')
     def expr(self, p):
         return p.constant
@@ -363,7 +333,7 @@ class SQLParser(Parser):
 
     @_('TRUE')
     def constant(self, p):
-        return  Constant(value=True)
+        return Constant(value=True)
 
     @_('FALSE')
     def constant(self, p):
@@ -385,6 +355,10 @@ class SQLParser(Parser):
     def identifier(self, p):
         return Identifier(value=p.ID)
 
+    @_('PARAMETER')
+    def parameter(self, p):
+        return Parameter(value=p.PARAMETER)
+
     @_('')
     def empty(self, p):
         pass
